
/*simple selector and simple rulset test*/
S1 {prop1 : value1}

/*Simple selector list and simple ruleset test*/
s1,s2 {color: black ; background: white}

/*descendants and child selector list, simple ruleset test*/
s1 s2, S3 > s4 {prop1 : value1 ; prop2 : value2}
