body { 

	background-color: #E5E5E5; 

	scrollbar-face-color: #CCCCCC; 

	scrollbar-highlight-color: #FFFFFF; 

	scrollbar-shadow-color: #CCCCCC; 

	scrollbar-3dlight-color: #D1D7DC; 

	scrollbar-arrow-color:  #000000; 

	scrollbar-track-color: #FFFFFF; 

	scrollbar-darkshadow-color: #000000; 

} 

 

font, th, td, p { 

	font-family: Verdana, Arial, Helvetica, sans-serif; 

	font-size: 11px;  

} 

 

h1, h2	{ font-size: 11px; color: #000000; font-weight: bold; } 

 

a:link, a:active, a:visited	{ color: #000000; } 

 

a:hover	{ color: #CC0000; text-decoration: underline; } 

 

hr	{ height: 0px; border: solid #CCCCCC 0px; border-top-width: 1px; } 

 

small	{ font-size: 10px; } 

 

input, textarea, select { 

	font: normal 11px Verdana, Arial, Helvetica, sans-serif; 

	color: #000000; 

	border-color: #000000; 

} 

 

input { text-indent: 2px; } 

 


input.post, textarea.post, select { 

	background-color: #FFFFFF;  

} 

 


th	{ 

	font-size: 11px; color: #CCCCCC; font-weight: bold; 

	background-color: #000000; height: 25px; 

	background-image: url(/~wiceyto/test/templates/blacknwhite/images/cellpic3.gif); 

} 

 


.fontspec, .tablefont { 

	font-family: Verdana, Arial, Helvetica, sans-serif; 

	font-size: 11px;  

} 

 

.navbartext, .navbarfont	{ 

	font-size: 11px; color: #000000; font-weight: bold;  

} 

 

.navbartext a, .navbarfont a	{ 

	color: #000000; font-weight: bold; text-decoration: none;  

} 

 

.navbartext a:hover, .navbarfont a:hover	{ 

	color: #CC0000; text-decoration: none;  

} 

 

.tablespec, .guestbook	{ background-color: #FFFFFF; border: 2px #000000 solid; } 

.tablespec th, .tablespec td	{ color: #000000; background-color: #CCCCCC; } 

.tablespec th 		{ background-image: none; } 

 

.messageblock	{  

	border: dashed 1px;  

	margin-right: 4em; margin-left: 4em; 

	padding: 3em; 

} 

 

/* $MessageOpenCode - the body of text of the posts */ 

.messagebody		{ font-size: 12px; line-height: 18px; } 

.messagebody a		{ color: #000000; text-decoration: underline; } 

.messagebody a:hover	{ color: #CC0000; text-decoration: underline; } 

 


.newcode	{ font-size: 11px; color: #CC0000; font-weight: bold; } 

.admincode	{ font-size: 11px; color: #990000; font-style: bold; } 

 


.bodyline	{ background-color: #FFFFFF; border: 1px #000000 solid; } 

 


.quote, .code { 

	background-color: #FAFAFA; border: #D1D7DC; border-style: solid; 

	border-top-width: 1px; border-right-width: 1px; 

	border-bottom-width: 1px; border-left-width: 1px;  

} 

 

.quote { 

	font-family: Verdana, Arial, Helvetica, sans-serif;  

	font-size: 11px; 

	color: #444444; line-height: 125%; 

} 

 

.code { 

	font-family: Courier, 'Courier New', sans-serif;  

	font-size: 11px;  

	color: #CC0000; 

} 

 


input.button { 

	font-family: Verdana, Arial, Helvetica, sans-serif; 

	font-size: 11px;  

	color: #000000; 

	background-color: #FFFFFF; 

} 

 

/* Format button rollover help line. Actually it's a text box  

 set to the same color as the background so no one will know. */ 

.helpline	{ background-color: #CCCCCC; border-style: none; } 

 

/* additional table cell colors and backgrounds */ 

td.row2		{ background-color: #CCCCCC; } 

td.row1		{ background-color: #CCCCCC; } 

td.row3		{ background-color: #D1D7DC; } 

 

/* additional general text */ 

.gen		{ font-size: 12px; } 

.genmed		{ font-size: 11px; } 

.gensmall	{ font-size: 10px; } 

.gen, .genmed, .gensmall	{ color: #000000; } 

a.gen, a.genmed, a.gensmall	{ color: #000000; text-decoration: none; } 

a.gen:hover, a.genmed:hover, a.gensmall:hover	{ color: #CC0000; text-decoration: underline; } 

 

/* import fancy styles. For IE only. NS4.x doesn't use the @import function */ 

@import url("/your.site/webbbs/themes/formIE.css"); 

 

/* END of blacknwhite.css */ 

 

 

 

/* Appendix.2-2: Example fancy styles CSS file 

Paste these into a text file and save as formIE.css */ 

 

/* Fancy form styles for IE */ 

 

input, textarea, select { 

border-top-width : 1px;  

border-right-width : 1px;  

border-bottom-width : 1px;  

border-left-width : 1px;   

} 

 

input { text-indent : 2px; } 

 

input.button { 

border-top-width : 1px;  

border-right-width : 1px;  

border-bottom-width : 1px;  

border-left-width : 1px;   

} 

 

.postbody { line-height: 18px} 

.magic {
    margin-left: -20px;
} 

/* END of formIE.css */ 
